@@ -200,6 +200,10 @@ QString AppConfig::autoConfigServer() const { return m_AutoConfigServer; }
 void AppConfig::loadSettings()
 {
     m_ScreenName        = loadSetting(kScreenName, QHostInfo::localHostName()).toString();
+    if (m_ScreenName.isEmpty()) {
+       m_ScreenName = QHostInfo::localHostName();
+    }
+
     m_Port              = loadSetting(kPort, 24800).toInt();
     m_Interface         = loadSetting(kInterfaceSetting).toString();
     m_LogLevel          = loadSetting(kLogLevel, 0).toInt();
@@ -233,7 +237,7 @@ void AppConfig::loadSettings()
     m_UseExternalConfig         = loadSetting(kUseExternalConfig, false).toBool();
     m_ConfigFile                = loadSetting(kConfigFile, QDir::homePath() + "/" + synergyConfigName).toString();
     m_UseInternalConfig         = loadSetting(kUseInternalConfig, false).toBool();
-    m_ClientGroupChecked        = loadSetting(kGroupClientCheck, true).toBool();
+    m_ClientGroupChecked        = loadSetting(kGroupClientCheck, false).toBool();
     m_ServerHostname            = loadSetting(kServerHostname).toString();
 
     //only change the serial key if the settings being loaded contains a key
@@ -263,7 +267,7 @@ void AppConfig::loadSettings()
 
 void AppConfig::saveSettings()
 {
-    setCommonSetting(kWizardLastRun, kWizardVersion);
+    setCommonSetting(kWizardLastRun, m_WizardLastRun);
     setCommonSetting(kLoadSystemSettings, m_LoadFromSystemScope);
 
     if (isWritable()) {
@@ -424,7 +428,7 @@ bool AppConfig::isCryptoAvailable() const {
     bool result {true};
 
 #ifndef SYNERGY_ENTERPRISE
-    result = (edition() == kPro || edition() == kBusiness);
+    result = (edition() == kPro || edition() == kPro_China || edition() == kBusiness);
 #endif
 
     return result;
@@ -444,6 +448,12 @@ void AppConfig::setMinimizeToTray(bool newValue) {
     setSettingModified(m_MinimizeToTray, newValue);
 }
 
+bool AppConfig::getLanguageSync() const { return m_LanguageSync; }
+
+void AppConfig::setLanguageSync(bool newValue) {
+    setSettingModified(m_LanguageSync, newValue);
+}
+
 bool AppConfig::getMinimizeToTray() { return m_MinimizeToTray; }
 
 QString AppConfig::settingName(AppConfig::Setting name) {
@@ -529,7 +539,7 @@ bool AppConfig::getUseExternalConfig() const {
     return m_UseExternalConfig;
 }
 
-QString AppConfig::getConfigFile() const {
+const QString& AppConfig::getConfigFile() const {
     return m_ConfigFile;
 }
 
