@@ -49,6 +49,7 @@ const int kWizardVersion = 8;
 
 class QSettings;
 class SettingsDialog;
+class ServerConfig;
 
 enum ProcessMode {
     Service,
@@ -62,6 +63,7 @@ class AppConfig: public QObject, public GUI::Config::ConfigBase
     friend class SettingsDialog;
     friend class MainWindow;
     friend class SetupWizard;
+    friend class ServerConfig;
 
     public:
         AppConfig();
@@ -110,6 +112,8 @@ class AppConfig: public QObject, public GUI::Config::ConfigBase
 
         void setAutoHide(bool b);
         bool getAutoHide();
+        void setLanguageSync(bool b);
+        bool getLanguageSync() const;
 #ifndef SYNERGY_ENTERPRISE
         bool activationHasRun() const;
         AppConfig& activationHasRun(bool value);
@@ -123,7 +127,7 @@ class AppConfig: public QObject, public GUI::Config::ConfigBase
 
         bool    getServerGroupChecked() const;
         bool    getUseExternalConfig() const;
-        QString getConfigFile() const;
+        const QString& getConfigFile() const;
         bool    getUseInternalConfig() const;
         bool    getClientGroupChecked() const;
         QString getServerHostname() const;
@@ -240,6 +244,7 @@ protected:
         int m_LastExpiringWarningTime;
         bool m_ActivationHasRun;
         bool m_MinimizeToTray;
+        bool m_LanguageSync           = true;
 
         bool m_ServerGroupChecked;
         bool m_UseExternalConfig;
